@@ -17,13 +17,14 @@
 #'   a valid partitioning scheme.  See help for functions CreateGroupPartition,
 #'   CreateRandomPartition, CreateStratifiedPartition, CreateUserPartition
 #'   and CreateDatetimePartitionSpecification.
-#' @param targetType character. Optional. Used to specify the targetType to use for a project when
-#'   it is ambiguous, i.e. a numeric target with a few unique values that could be used for either
-#'   regression or multiclass. Valid options are 'Binary', 'Multiclass', 'Regression'. See
-#'   \code{TargetType} for an easier way to keep track of the options.
+#' @param targetType character. Optional. Used to specify the targetType to use for a project.
+#'   Valid options are "Binary", "Multiclass", "Regression". Set to "Multiclass" to enable
+#'   multiclass modeling. Otherwise, it can help to disambiguate, i.e. telling DataRobot how to
+#'   handle a numeric target with a few unique values that could be used for either multiclass
+#'   or regression. See \code{TargetType} for an easier way to keep track of the options.
 #' @param mode character. Optional. Specifies the autopilot mode used to start the
-#'   modeling project; valid options are 'auto' (fully automatic,
-#'   the current DataRobot default, obtained when mode = NULL), 'manual' and 'quick'
+#'   modeling project; valid options are "auto" (fully automatic,
+#'   the current DataRobot default, obtained when mode = NULL), "manual" and "quick"
 #' @param seed integer. Optional. Seed for the random number generator used in
 #'   creating random partitions for model fitting.
 #' @param positiveClass character. Optional. Target variable value corresponding to a positive
@@ -129,6 +130,14 @@ SetTarget <- function(project, target, metric = NULL, weights = NULL,
   ValidateParameterIn(targetType, TargetType)
   bodyList$targetType <- targetType
 
+  if (!is.null(partition) && !is(partition, "partition")) {
+    partitioningMethods <- c("CreateRandomPartition", "CreateStratifiedPartition",
+                             "CreateGroupPartition", "CreateUserPartition",
+                             "CreateDatetimePartitionSpecification")
+    stop("You must use a valid partition object to specify your partitioning.",
+         " See docs for ", paste0(lapply(partitioningMethods, sQuote), collapse = ", "),
+         " for examples.")
+  }
   if (!is.null(partition)) {
     if (partition$cvMethod == cvMethods$DATETIME) {
       partition <- as.dataRobotDatetimePartitionSpecification(partition)
