@@ -21,7 +21,7 @@
 #' \dontrun{
 #'   projectId <- "59a5af20c80891534e3c2bde"
 #'   modelId <- "5996f820af07fc605e81ead4"
-#'   model <- GetModelObject(projectId, modelId)
+#'   model <- GetModel(projectId, modelId)
 #'   summary(model)
 #' }
 #' @export
@@ -118,7 +118,8 @@ summary.listOfBlueprints <- function(object, nList = 6, ...) {
     projectId <- object[[i]]$projectId
     upFrame <- data.frame(projectId = projectId, modelType = modelType,
                           expandedModel = expandedModel,
-                          blueprintId = blueprintId)
+                          blueprintId = blueprintId,
+                          stringsAsFactors = FALSE)
     sumFrame <- rbind.data.frame(sumFrame, upFrame)
   }
   nBlue <- length(object)
@@ -144,7 +145,7 @@ summary.listOfBlueprints <- function(object, nList = 6, ...) {
 #' @examples
 #' \dontrun{
 #'   projectId <- "59a5af20c80891534e3c2bde"
-#'   featureList <- CreateFeatureList(projectId, "myFeaturelist", c("feature1", "feature2"))
+#'   featureList <- CreateFeaturelist(projectId, "myFeaturelist", c("feature1", "feature2"))
 #'   summary(featureList)
 #' }
 #' @export
@@ -209,7 +210,7 @@ summary.listOfFeaturelists <- function(object, nList = 6, ...) {
 #' @examples
 #' \dontrun{
 #'   projectId <- "59a5af20c80891534e3c2bde"
-#'   models <- GetAllModels(projectId)
+#'   models <- ListModels(projectId)
 #'   summary(models)
 #' }
 #' @export
